"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _portal = require("@gorhom/portal");

var _nonSecure = require("nanoid/non-secure");

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _calculations = require("../../utils/calculations");

var _constants = require("../../constants");

var _styles = _interopRequireDefault(require("./styles"));

var _hooks = require("../../hooks");

var _styleGuide = _interopRequireDefault(require("../../styleGuide"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// Utils
const HoldItemComponent = ({
  items,
  bottom,
  containerStyles,
  disableMove,
  menuAnchorPosition,
  children
}) => {
  const {
    state,
    menuProps
  } = (0, _hooks.useInternal)();
  const isActive = (0, _reactNativeReanimated.useSharedValue)(false);
  const containerRef = (0, _reactNativeReanimated.useAnimatedRef)();
  const itemRectY = (0, _reactNativeReanimated.useSharedValue)(0);
  const itemRectX = (0, _reactNativeReanimated.useSharedValue)(0);
  const itemRectWidth = (0, _reactNativeReanimated.useSharedValue)(0);
  const itemRectHeight = (0, _reactNativeReanimated.useSharedValue)(0);
  const itemScale = (0, _reactNativeReanimated.useSharedValue)(1);
  const transformValue = (0, _reactNativeReanimated.useSharedValue)(0);
  const transformOrigin = (0, _reactNativeReanimated.useSharedValue)(menuAnchorPosition || 'top-right');
  const deviceOrientation = (0, _hooks.useDeviceOrientation)();
  const key = (0, _react.useMemo)(() => `hold-item-${(0, _nonSecure.nanoid)()}`, []);
  const menuHeight = (0, _react.useMemo)(() => {
    const itemsWithSeperator = items.filter(item => item.withSeperator);
    return (0, _calculations.calculateMenuHeight)(items.length, itemsWithSeperator.length);
  }, [items]);

  const activateAnimation = ctx => {
    'worklet';

    if (!ctx.didMeasureLayout) {
      const measured = (0, _reactNativeReanimated.measure)(containerRef);
      itemRectY.value = measured.pageY;
      itemRectX.value = measured.pageX;
      itemRectHeight.value = measured.height;
      itemRectWidth.value = measured.width;

      if (!menuAnchorPosition) {
        const position = (0, _calculations.getTransformOrigin)(measured.pageX, itemRectWidth.value, deviceOrientation === 'portrait' ? _constants.WINDOW_WIDTH : _constants.WINDOW_HEIGHT, bottom);
        transformOrigin.value = position;
      }
    }
  };

  const calculateTransformValue = () => {
    'worklet';

    const height = deviceOrientation === 'portrait' ? _constants.WINDOW_HEIGHT : _constants.WINDOW_WIDTH;
    const isAnchorPointTop = transformOrigin.value.includes('top');
    let tY = 0;

    if (!disableMove) {
      if (isAnchorPointTop) {
        const topTransform = itemRectY.value + itemRectHeight.value + menuHeight + _styleGuide.default.spacing * 2;
        tY = topTransform > height ? height - topTransform : 0;
      } else {
        const bototmTransform = itemRectY.value - menuHeight;
        tY = bototmTransform < 0 ? -bototmTransform + _styleGuide.default.spacing * 2 : 0;
      }
    }

    return tY;
  };

  const setMenuProps = () => {
    'worklet';

    menuProps.value = {
      itemHeight: itemRectHeight.value,
      itemWidth: itemRectWidth.value,
      itemY: itemRectY.value,
      itemX: itemRectX.value,
      anchorPosition: transformOrigin.value,
      menuHeight: menuHeight,
      items,
      transformValue: transformValue.value
    };
  };

  const scaleBack = () => {
    'worklet';

    itemScale.value = (0, _reactNativeReanimated.withTiming)(1, {
      duration: _constants.HOLD_ITEM_TRANSFORM_DURATION / 2
    });
  };

  const longPressGestureEvent = (0, _reactNativeReanimated.useAnimatedGestureHandler)({
    onActive: (_, context) => {
      if (!context.didMeasureLayout) {
        activateAnimation(context);
        transformValue.value = calculateTransformValue();
        setMenuProps();
        context.didMeasureLayout = true;
      }

      if (!isActive.value) {
        itemScale.value = (0, _reactNativeReanimated.withTiming)(_constants.HOLD_ITEM_SCALE_DOWN_VALUE, {
          duration: _constants.HOLD_ITEM_SCALE_DOWN_DURATION
        }, isFinised => {
          const isListValid = items && items.length > 0;

          if (isFinised && isListValid) {
            state.value = _constants.CONTEXT_MENU_STATE.ACTIVE;
            isActive.value = true;
            scaleBack();
          } // TODO: Warn user if item list is empty or not given

        });
      }
    },
    onFinish: (_, context) => {
      context.didMeasureLayout = false;
      scaleBack();
    }
  });
  const animatedContainerStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const animateOpacity = () => (0, _reactNativeReanimated.withDelay)(_constants.HOLD_ITEM_TRANSFORM_DURATION, (0, _reactNativeReanimated.withTiming)(1, {
      duration: 0
    }));

    return {
      opacity: isActive.value ? 0 : animateOpacity(),
      transform: [{
        scale: isActive.value ? (0, _reactNativeReanimated.withTiming)(1, {
          duration: _constants.HOLD_ITEM_TRANSFORM_DURATION
        }) : itemScale.value
      }]
    };
  });

  const containerStyle = _react.default.useMemo(() => [containerStyles, animatedContainerStyle], [containerStyles, animatedContainerStyle]);

  const animatedPortalStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const animateOpacity = () => (0, _reactNativeReanimated.withDelay)(_constants.HOLD_ITEM_TRANSFORM_DURATION, (0, _reactNativeReanimated.withTiming)(0, {
      duration: 0
    }));

    let tY = calculateTransformValue();

    const transformAnimation = () => disableMove ? 0 : isActive.value ? (0, _reactNativeReanimated.withSpring)(tY, _constants.SPRING_CONFIGURATION) : (0, _reactNativeReanimated.withTiming)(-0.1, {
      duration: _constants.HOLD_ITEM_TRANSFORM_DURATION
    });

    return {
      zIndex: 10,
      position: 'absolute',
      top: itemRectY.value,
      left: itemRectX.value,
      width: itemRectWidth.value,
      height: itemRectHeight.value,
      opacity: isActive.value ? 1 : animateOpacity(),
      transform: [{
        translateY: transformAnimation()
      }, {
        scale: isActive.value ? (0, _reactNativeReanimated.withTiming)(1, {
          duration: _constants.HOLD_ITEM_TRANSFORM_DURATION
        }) : itemScale.value
      }]
    };
  });
  const portalContainerStyle = (0, _react.useMemo)(() => [_styles.default.holdItem, animatedPortalStyle], [animatedPortalStyle]);
  const animatedPortalProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    pointerEvents: isActive.value ? 'auto' : 'none'
  }));
  (0, _reactNativeReanimated.useAnimatedReaction)(() => state.value, _state => {
    if (_state === _constants.CONTEXT_MENU_STATE.END) {
      isActive.value = false;
    }
  });
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.LongPressGestureHandler, {
    minDurationMs: 150,
    onHandlerStateChange: longPressGestureEvent
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    ref: containerRef,
    style: containerStyle
  }, children)), /*#__PURE__*/_react.default.createElement(_portal.Portal, {
    key: key,
    name: key
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    key: key,
    style: portalContainerStyle,
    animatedProps: animatedPortalProps
  }, children)));
};

const HoldItem = /*#__PURE__*/(0, _react.memo)(HoldItemComponent);
var _default = HoldItem;
exports.default = _default;
//# sourceMappingURL=HoldItem.js.map