import React, { useMemo, useCallback } from 'react';
import { TouchableOpacity, Text } from 'react-native';
import { TouchableOpacity as GHTouchableOpacity } from 'react-native-gesture-handler';
import Animated, { useAnimatedStyle } from 'react-native-reanimated';
import Seperator from './Seperator';
import styles from './styles';
import { useInternal } from '../../hooks';
import { CONTEXT_MENU_STATE, IS_IOS } from '../../constants';
import { BORDER_LIGHT_COLOR, BORDER_DARK_COLOR, MENU_TITLE_COLOR, MENU_TEXT_DESTRUCTIVE_COLOR, MENU_TEXT_DARK_COLOR, MENU_TEXT_LIGHT_COLOR } from './constants';
import isEqual from 'lodash.isequal';
const ItemComponent = IS_IOS ? TouchableOpacity : GHTouchableOpacity;
const AnimatedTouchable = Animated.createAnimatedComponent(ItemComponent);

const MenuItemComponent = ({
  item,
  isLast,
  theme
}) => {
  const {
    state
  } = useInternal();
  const borderStyles = useAnimatedStyle(() => {
    const borderBottomColor = theme === 'dark' ? BORDER_DARK_COLOR : BORDER_LIGHT_COLOR;
    return {
      borderBottomColor,
      borderBottomWidth: isLast ? 0 : 1
    };
  }, [theme, isLast]);
  const textColor = useMemo(() => {
    return {
      color: item.isTitle ? MENU_TITLE_COLOR : item.isDestructive ? MENU_TEXT_DESTRUCTIVE_COLOR : theme === 'dark' ? MENU_TEXT_DARK_COLOR : MENU_TEXT_LIGHT_COLOR
    };
  }, [item, theme]);
  const handleOnPress = useCallback(() => {
    if (!item.isTitle) {
      if (item.onPress) item.onPress();
      state.value = CONTEXT_MENU_STATE.END;
    }
  }, [state, item]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(AnimatedTouchable, {
    onPress: handleOnPress,
    activeOpacity: !item.isTitle ? 0.4 : 1,
    style: [styles.menuItem, borderStyles]
  }, /*#__PURE__*/React.createElement(Text, {
    style: [item.isTitle ? styles.menuItemTitleText : styles.menuItemText, textColor]
  }, item.text), !item.isTitle && item.icon && item.icon()), item.withSeperator && /*#__PURE__*/React.createElement(Seperator, {
    theme: theme
  }));
};

const MenuItem = /*#__PURE__*/React.memo(MenuItemComponent, isEqual);
export default MenuItem;
//# sourceMappingURL=MenuItem.js.map